==> library-0.5.2-sources.jar: app/valuationcontrol/multimodule/library/xlhandler/CellValueHelper.java <==
package app.valuationcontrol.multimodule.library.xlhandler;

import app.valuationcontrol.multimodule.library.entities.Variable;
import app.valuationcontrol.multimodule.library.entities.VariableValue;
import app.valuationcontrol.multimodule.library.helpers.DataPeriod;

public class CellValueHelper {
  public static final int AZ_COUNTER = 26;

  public static GenericSheet.CellValue cellValueOf(VariableValue variableValue) {

    Variable variable = variableValue.getAttachedVariable();

    var columnIndex =
        variable.columnOfSegmentAndPeriod(
            variableValue.getAttachedSegment(), variableValue.getPeriod());

    return new GenericSheet.CellValue(variableValue.getValue(), columnIndex, variable.getRow());
  }

  /**
   * Returns the A1 address of the formula
   *
   * @param dataPeriod indicates which dataperiod we should generate address for
   * @return the generated address as a String
   */
  public static String generateAddress(Variable variable, DataPeriod dataPeriod) {
    int columnToAssess;
    if (variable.isSingleOrConstantValue()) {
      columnToAssess =
          (variable.getAttachedModel().getConstantColumn())
              + dataPeriod.getSegmentOffsetAsInteger();
    } else {
      columnToAssess = variable.getPrimaryColumn() + dataPeriod.getTotalOffsetAsInteger();
    }
    return generateAddress(variable, columnToAssess);
  }

  /**
   * Returns the A1 address of the formula
   *
   * @param columnToAssess indicates which column we should generate address for
   * @return the A1 address of the formula
   */
  public static String generateAddress(Variable variable, int columnToAssess) {
    String returnString;
    String prefix = "";
    String column;

    int rowToAssess = variable.getRow() + 1;
    int multiplier = columnToAssess / AZ_COUNTER;
    int rest = columnToAssess % AZ_COUNTER;

    // Defining column prefix AA
    if (multiplier >= 1) {
      prefix = Character.toString((char) (65 + multiplier - 1));
    }

    column = prefix + (char) (65 + rest);

    if (variable.isSingleOrConstantValue()) {
      returnString = "$" + column + "$" + rowToAssess;
    } else {
      returnString = column + rowToAssess;
    }

    return returnString;
  }
}

==> library-0.5.4-sources.jar: app/valuationcontrol/multimodule/library/xlhandler/CellValueHelper.java <==
package app.valuationcontrol.multimodule.library.xlhandler;

import app.valuationcontrol.multimodule.library.entities.Area;
import app.valuationcontrol.multimodule.library.entities.Model;
import app.valuationcontrol.multimodule.library.entities.Variable;
import app.valuationcontrol.multimodule.library.entities.VariableValue;
import app.valuationcontrol.multimodule.library.helpers.DataPeriod;

public class CellValueHelper {
  public static final int AZ_COUNTER = 26;

  public static GenericSheet.CellValue cellValueOf(VariableValue variableValue) {

    Variable variable = variableValue.getAttachedVariable();

    var columnIndex =
        variable.columnOfSegmentAndPeriod(
            variableValue.getAttachedSegment(), variableValue.getPeriod());

    return new GenericSheet.CellValue(variableValue.getValue(), columnIndex, variable.getRow());
  }

  /**
   * Returns the A1 address of the formula
   *
   * @param dataPeriod indicates which dataperiod we should generate address for
   * @return the generated address as a String
   */
  public static String generateAddress(Variable variable, DataPeriod dataPeriod) {
    int columnToAssess;
    if (variable.isSingleOrConstantValue()) {
      columnToAssess =
          (variable.getAttachedModel().getConstantColumn())
              + dataPeriod.getSegmentOffsetAsInteger();
    } else {
      columnToAssess = variable.getPrimaryColumn() + dataPeriod.getTotalOffsetAsInteger();
    }
    return generateAddress(variable, columnToAssess);
  }

  public static String getAreaSheetNameWithQuotes(Area area) {
    Model attachedModel = area.getAttachedModel();
    return "'" + attachedModel.getAreaStringHashMap().get(area) + "'";
  }

  /**
   * Returns the A1 address of the formula
   *
   * @param columnToAssess indicates which column we should generate address for
   * @return the A1 address of the formula
   */
  private static String generateAddress(Variable variable, int columnToAssess) {
    String returnString;
    String prefix = "";
    String column;

    int rowToAssess = 1 + variable.getRow(); // Checks wether the variable should use area
    int multiplier = columnToAssess / AZ_COUNTER;
    int rest = columnToAssess % AZ_COUNTER;

    // Defining column prefix AA
    if (multiplier >= 1) {
      prefix = Character.toString((char) (65 + multiplier - 1));
    }

    column = prefix + (char) (65 + rest);

    if (variable.isSingleOrConstantValue()) {
      returnString = "$" + column + "$" + rowToAssess;
    } else {
      returnString = column + rowToAssess;
    }

    if (variable.getAttachedModel().getUseAreaAddress()) {
      returnString = getAreaSheetNameWithQuotes(variable.getVariableArea()) + "!" + returnString;
    }

    return returnString;
  }
}
